 - Perimeter81 Public (**Unofficial**) API

 - A python wrapper of Perimeter81 [public API](https://support.perimeter81.com/docs/api-getting-started)

 - See [Examples Repo](https://github.com/vladbekker-p81/perimeter81-api-examples) for API usage examples
 - Read the [docs](https://vladbekker-p81.github.io/perimeter81-api/api.html)


